package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.HxBigPicService;
import com.ailanyin.common.result.AjaxResult;
import com.ailanyin.common.result.CommonPage;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.model.HxBigPic;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/24 0024 上午 11:14
 */

@RestController
@RequestMapping("/hx/bigPic")
@Api(tags = "红峡大图管理")
public class HxBigPicController {

    @Autowired
    private HxBigPicService hxBigPicService;

    //@PreAuthorize("hasAuthority('hx:dict:list')")
    @GetMapping("/list")
    @ApiOperation(value = "红峡大图列表")
    public CommonPage list(HxBigPic hxBigPic,
                           @RequestParam(value = "pageSize", required = false) Integer pageSize,
                           @RequestParam(value = "pageNum", required = false) Integer pageNum) {

        if (EmptyUtil.isNotEmpty(pageSize) && EmptyUtil.isNotEmpty(pageNum)) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<HxBigPic> list = hxBigPicService.selectList(hxBigPic);
        return CommonPage.restPage(list);
    }

    @GetMapping("/getByType")
    @ApiOperation(value = "根据type获取")
    public AjaxResult getByType(@RequestParam("type") String type) {
        HxBigPic bigPic = hxBigPicService.getByType(type);
        return AjaxResult.success(bigPic);
    }

    //@PreAuthorize("hasAuthority('hx:dict:add')")
    @PostMapping
    @ApiOperation(value = "新增红峡大图")
    public AjaxResult addHxBigPic(@RequestBody HxBigPic hxBigPic) {
        hxBigPicService.addHxBigPic(hxBigPic);
        return AjaxResult.success();
    }

    //@PreAuthorize("hasAuthority('hx:dict:update')")
    @PutMapping
    @ApiOperation(value = "修改红峡大图")
    public AjaxResult updateHxBigPic(@RequestBody HxBigPic hxBigPic) {
        hxBigPicService.updateHxBigPic(hxBigPic);
        return AjaxResult.success();
    }

    //@PreAuthorize("hasAuthority('hx:dict:delete')")
    @DeleteMapping
    @ApiOperation(value = "删除红峡大图")
    public AjaxResult delHxBigPic(@RequestParam(value = "hxBigPicId") Long hxBigPicId) {
        hxBigPicService.delHxBigPicById(hxBigPicId);
        return AjaxResult.success();
    }
}
