package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.*;
import com.ailanyin.common.result.AjaxResult;
import com.ailanyin.common.utils.DateUtil;
import com.ailanyin.model.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import oshi.hardware.platform.mac.MacPowerSource;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/12 0012 上午 10:49
 */

@RestController
@RequestMapping("/hx/cockpitOverview")
@Api(tags = "大图: 驾驶舱总览")
public class HxCockpitOverviewController {

    @Autowired
    private HxChargeQuantityService hxChargeQuantityService;
    @Autowired
    private HxTodayDynamicService hxTodayDynamicService;
    @Autowired
    private HxProductCompletionOverviewService hxProductCompletionOverviewService;
    @Autowired
    private HxProductionResponsibilityService hxProductionResponsibilityService;
    @Autowired
    private HxAnnualTargetService hxAnnualTargetService;
    @Autowired
    private HxRevenueProfitService hxRevenueProfitService;
    @Autowired
    private HxMonthDynamicService hxMonthDynamicService;

    @GetMapping("/chargeQuantityList")
    @ApiOperation(value = "装药量概况")
    public AjaxResult chargeQuantity() {
        List<HxChargeQuantity> list = hxChargeQuantityService.selectHxChargeQuantityList(new HxChargeQuantity());
        return AjaxResult.success(list);
    }

    @GetMapping("/todayDynamics")
    @ApiOperation(value = "今日动态")
    public AjaxResult todayDynamics() {
        Map map = new HashMap(2);
        HxTodayDynamic dynamic = new HxTodayDynamic();
        dynamic.setTodayDate(DateUtil.getDate("yyyy-MM-dd"));
        List<HxTodayDynamic> list = hxTodayDynamicService.selectHxTodayDynamicList(dynamic);
        HxMonthDynamic hxMonthDynamic = new HxMonthDynamic();
        hxMonthDynamic.setMonth(DateUtil.getDate("yyyy-MM"));
        List<HxMonthDynamic> list1 = hxMonthDynamicService.getListByParam(hxMonthDynamic);
        map.put("month",list1.size() > 0 ? list1.get(0):new HxMonthDynamic());
        map.put("today",list.size() > 0 ? list.get(0):new HxTodayDynamic());
        return AjaxResult.success(map);
    }

    @GetMapping("/productCompletion")
    @ApiOperation(value = "交付产品完成情况")
    public AjaxResult productCompletion() {
        List<HxProductCompletionOverview> list = hxProductCompletionOverviewService.selectHxProductCompletionOverviewList(new HxProductCompletionOverview());
        return AjaxResult.success(list);
    }

    @GetMapping("/productionResponsibility")
    @ApiOperation(value = "生产责任令完成概况")
    public AjaxResult productionResponsibility() {
        return AjaxResult.success(hxProductionResponsibilityService.getPic());
    }

    @GetMapping("/annualTargetAndPic")
    @ApiOperation(value = "全年目标以及大图")
    public AjaxResult annualTargetAndPic() {
        HxAnnualTarget hxAnnualTarget = new HxAnnualTarget();
        hxAnnualTarget.setYear(DateUtil.dateTimeNow("yyyy"));
        List<HxAnnualTarget> list = hxAnnualTargetService.selectHxAnnualTargetList(hxAnnualTarget);
        return AjaxResult.success(list);
    }

    @GetMapping("/revenueProfile")
    @ApiOperation(value = "收入概况")
    public AjaxResult revenueProfile() {
        return AjaxResult.success(hxRevenueProfitService.getRevenueProfilePic());
    }

    @GetMapping("/profitProfile")
    @ApiOperation(value = "利润概况")
    public AjaxResult profitProfile() {
        return AjaxResult.success(hxRevenueProfitService.getProfitProfilePic());
    }

    @GetMapping("/businessResponsibility")
    @ApiOperation(value = "经营责任书概况")
    public AjaxResult businessResponsibility() {
        return AjaxResult.success(hxRevenueProfitService.getBusinessResponsibility());
    }
}
