package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.HxFactoryOperateIndexService;
import com.ailanyin.common.result.AjaxResult;
import com.ailanyin.common.result.CommonPage;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.ExcelUtil;
import com.ailanyin.model.HxFactoryOperateIndex;
import com.ailanyin.model.HxFactoryOperateIndexTarget;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/17 0017 上午 10:04
 */
@RestController
@RequestMapping("/hx/factoryOperateIndex")
@Api(tags = "经营管理: 全厂经营指标管理")
public class HxFactoryOperateIndexController {

    @Autowired
    private HxFactoryOperateIndexService hxFactoryOperateIndexService;

    @GetMapping("/list")
    @ApiOperation(value = "红峡全厂经营指标列表")
    public CommonPage list(HxFactoryOperateIndex hxFactoryOperateIndex,
                           @RequestParam(value = "pageSize", required = false) Integer pageSize,
                           @RequestParam(value = "pageNum", required = false) Integer pageNum) {

        if (EmptyUtil.isNotEmpty(pageSize) && EmptyUtil.isNotEmpty(pageNum)) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<HxFactoryOperateIndex> list = hxFactoryOperateIndexService.selectList(hxFactoryOperateIndex);
        return CommonPage.restPage(list);
    }

    @PostMapping("/importData1")
    @ApiOperation(value = "导入[目标]Excel列表")
    //@PreAuthorize("hasAuthority('hx:productCompletion:import')")
    public AjaxResult importData1(MultipartFile file) throws Exception {
        List<HxFactoryOperateIndexTarget> list = ExcelUtil.importExcel(file, HxFactoryOperateIndexTarget.class);
        hxFactoryOperateIndexService.importData1(list);
        return AjaxResult.success();
    }

    @PostMapping("/importData2")
    @ApiOperation(value = "导入[实际]Excel列表")
    //@PreAuthorize("hasAuthority('hx:productCompletion:import')")
    public AjaxResult importData2(MultipartFile file) throws Exception {
        List<HxFactoryOperateIndex> list = ExcelUtil.importExcel(file, HxFactoryOperateIndex.class);
        hxFactoryOperateIndexService.importData(list);
        return AjaxResult.success();
    }

    @GetMapping("/importTemplate1")
    @ApiOperation(value = "导出实际模板")
    //@PreAuthorize("hasAuthority('system:user:import')")
    public AjaxResult importTemplate1() throws Exception {
        return AjaxResult.success(ExcelUtil.exportExcel(new ArrayList<>(), "全厂经营指标实际表", "全厂经营指标实际", HxFactoryOperateIndex.class, "全厂经营指标实际"));
    }

    @GetMapping("/importTemplate2")
    @ApiOperation(value = "导出目标模板")
    //@PreAuthorize("hasAuthority('system:user:import')")
    public AjaxResult importTemplate2() throws Exception {
        return AjaxResult.success(ExcelUtil.exportExcel(new ArrayList<>(), "全厂经营指标目标表", "全厂经营指标目标", HxFactoryOperateIndexTarget.class, "全厂经营指标目标"));
    }
}
