package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.HxModelStationService;
import com.ailanyin.common.result.AjaxResult;
import com.ailanyin.common.result.CommonPage;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.ExcelUtil;
import com.ailanyin.model.HxModelStation;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/21 0021 上午 10:21
 */

@RestController
@RequestMapping("/hx/modelStation")
@Api(tags = "科研生产:项目管理:型号工位管理")
public class HxModelStationController {

    @Autowired
    private HxModelStationService hxModelStationService;

    @GetMapping("/list")
    @ApiOperation(value = "红峡型号工位列表")
    public CommonPage list(HxModelStation hxModelStation,
                           @RequestParam(value = "pageSize", required = false) Integer pageSize,
                           @RequestParam(value = "pageNum", required = false) Integer pageNum) {

        if (EmptyUtil.isNotEmpty(pageSize) && EmptyUtil.isNotEmpty(pageNum)) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<HxModelStation> list = hxModelStationService.selectList(hxModelStation);
        return CommonPage.restPage(list);
    }

    @PostMapping("/importData")
    @ApiOperation(value = "导入Excel列表")
    //@PreAuthorize("hasAuthority('hx:productCompletion:import')")
    public AjaxResult importData(MultipartFile file) throws Exception {
        List<HxModelStation> list = ExcelUtil.importExcel(file, HxModelStation.class);
        hxModelStationService.importData(list);
        return AjaxResult.success();
    }

    @GetMapping("/importTemplate")
    @ApiOperation(value = "导出模板")
    //@PreAuthorize("hasAuthority('system:user:import')")
    public AjaxResult importTemplate() throws Exception {
        return AjaxResult.success(ExcelUtil.exportExcel(new ArrayList<>(), "型号工位表", "型号工位", HxModelStation.class, "型号工位"));
    }
}
