package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.*;
import com.ailanyin.common.result.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/15 0015 下午 16:14
 */

@RestController
@RequestMapping("/hx/operating")
@Api(tags = "大图: 经营管理")
public class HxOperatingManagementController {

    @Autowired
    private HxStrategyIndexService hxStrategyIndexService;
    @Autowired
    private HxSynthesizeIndexService hxSynthesizeIndexService;
    @Autowired
    private HxInformationPublicityService hxInformationPublicityService;
    @Autowired
    private HxComprehensivePlanService hxComprehensivePlanService;
    @Autowired
    private HxCostAnalysisService hxCostAnalysisService;
    @Autowired
    private HxCivilIncomeService hxCivilIncomeService;
    @Autowired
    private HxMilitaryGeneralFactoryService hxMilitaryGeneralFactoryService;
    @Autowired
    private HxFactoryOperateIndexService hxFactoryOperateIndexService;
    @Autowired
    private HxDeptOperateIndexService hxDeptOperateIndexService;


    @GetMapping("/getHxStrategyIndexPic")
    @ApiOperation(value = "战略指标")
    public AjaxResult getHxStrategyIndexPic() {
        List<Map> list = hxStrategyIndexService.getHxStrategyIndexPic();
        return AjaxResult.success(list);
    }

    @GetMapping("/getHxSynthesizeIndexPic")
    @ApiOperation(value = "综合指标(type=1完成率/2=明细)")
    public AjaxResult getHxSynthesizeIndexPic(@RequestParam("type") String type) {
        return AjaxResult.success(hxSynthesizeIndexService.getHxSynthesizeIndexPic(type));
    }

    @GetMapping("/getInformationPublicityPic")
    @ApiOperation(value = "信息公示(type=1项目公示/2=信息公示)")
    public AjaxResult getInformationPublicityPic(@RequestParam("type") String type) {
        return AjaxResult.success(hxInformationPublicityService.getInformationPublicityPic(type));
    }

    @GetMapping("/getComprehensivePlanPic")
    @ApiOperation(value = "综合计划/绩效计划(type=1完成率/2=明细)")
    public AjaxResult getComprehensivePlanPic(@RequestParam("type") String type,
                                              @RequestParam(value = "month",required = false) String month) {
        return AjaxResult.success(hxComprehensivePlanService.getComprehensivePlanPic(type,month));
    }

    @GetMapping("/getCostAnalysisPic")
    @ApiOperation(value = "成本分析")
    public AjaxResult getCostAnalysisPic() {
        return AjaxResult.success(hxCostAnalysisService.getCostAnalysisPic());
    }

    @GetMapping("/getCivilIndustryPic")
    @ApiOperation(value = "民用产业(type=1总厂情况/2=合同及产品/3本月情况)")
    public AjaxResult getCivilIndustryPic(@RequestParam("type") String type) {
        return AjaxResult.success(hxCivilIncomeService.getCivilIndustryPic(type));
    }

    @GetMapping("/getMilitaryIndustryPic")
    @ApiOperation(value = "军用产业(type=1总厂情况/2=合同信息/3本月情况)")
    public AjaxResult getMilitaryIndustryPic(@RequestParam("type") String type) {
        return AjaxResult.success(hxMilitaryGeneralFactoryService.getMilitaryIndustryPic(type));
    }

    @GetMapping("/getFactoryOperateIndexPic")
    @ApiOperation(value = "收入,利润,EVA,两金(type=1全年/2=本月)")
    public AjaxResult getFactoryOperateIndexPic(@RequestParam("type") String type) {
        return AjaxResult.success(hxFactoryOperateIndexService.getFactoryOperateIndexPic(type));
    }

    @GetMapping("/getDeptOperateIndexPic")
    @ApiOperation(value = "部门经营指标完成率(type=1月度/2=全年)")
    public AjaxResult getDeptOperateIndexPic(@RequestParam("type") String type,
                                             @RequestParam(value = "month",required = false) String month) {
        return AjaxResult.success(hxDeptOperateIndexService.getDeptOperateIndexPic(type,month));
    }
}
