package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.HxQualitySystemService;
import com.ailanyin.common.result.AjaxResult;
import com.ailanyin.common.result.CommonPage;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.ExcelUtil;
import com.ailanyin.model.HxQualitySystemElements;
import com.ailanyin.model.HxQualitySystemReview;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/13 0013 下午 15:56
 */
@RestController
@RequestMapping("/hx/qualitySystem")
@Api(tags = "红峡质量体系管理")
public class HxQualitySystemController {

    @Autowired
    private HxQualitySystemService hxQualitySystemService;

    @GetMapping("/reviewList")
    @ApiOperation(value = "红峡质量体系审查列表")
    public CommonPage reviewList(HxQualitySystemReview hxQualitySystemReview,
                                 @RequestParam(value = "pageSize", required = false) Integer pageSize,
                                 @RequestParam(value = "pageNum", required = false) Integer pageNum) {

        if (EmptyUtil.isNotEmpty(pageSize) && EmptyUtil.isNotEmpty(pageNum)) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<HxQualitySystemReview> list = hxQualitySystemService.selectHxQualitySystemReviewList(hxQualitySystemReview);
        return CommonPage.restPage(list);
    }

    @PostMapping("/importReviewData")
    @ApiOperation(value = "导入体系审查Excel列表")
    //@PreAuthorize("hasAuthority('hx:productCompletion:import')")
    public AjaxResult importReviewData(MultipartFile file) throws Exception {
        List<HxQualitySystemReview> list = ExcelUtil.importExcel(file, HxQualitySystemReview.class);
        hxQualitySystemService.importReviewData(list);
        return AjaxResult.success();
    }

    @GetMapping("/importReviewTemplate")
    @ApiOperation(value = "导出体系审查模板")
    //@PreAuthorize("hasAuthority('system:user:import')")
    public AjaxResult importReviewTemplate() throws Exception {
        return AjaxResult.success(ExcelUtil.exportExcel(new ArrayList<>(), "质量体系审查表", "质量体系审查", HxQualitySystemReview.class, "质量体系审查"));
    }

    @GetMapping("/list")
    @ApiOperation(value = "红峡体系要素列表")
    public CommonPage list(HxQualitySystemElements hxQualitySystemElements,
                           @RequestParam(value = "pageSize", required = false) Integer pageSize,
                           @RequestParam(value = "pageNum", required = false) Integer pageNum) {

        if (EmptyUtil.isNotEmpty(pageSize) && EmptyUtil.isNotEmpty(pageNum)) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<HxQualitySystemElements> list = hxQualitySystemService.selectHxQualitySystemElementsList(hxQualitySystemElements);
        return CommonPage.restPage(list);
    }

    @PostMapping("/importData")
    @ApiOperation(value = "导入体系要素Excel列表")
    //@PreAuthorize("hasAuthority('hx:productCompletion:import')")
    public AjaxResult importData(MultipartFile file) throws Exception {
        List<HxQualitySystemElements> list = ExcelUtil.importExcel(file, HxQualitySystemElements.class);
        hxQualitySystemService.importData(list);
        return AjaxResult.success();
    }

    @GetMapping("/importTemplate")
    @ApiOperation(value = "导出体系要素模板")
    //@PreAuthorize("hasAuthority('system:user:import')")
    public AjaxResult importTemplate() throws Exception {
        return AjaxResult.success(ExcelUtil.exportExcel(new ArrayList<>(), "体系要素表", "体系要素", HxQualitySystemElements.class, "体系要素"));
    }

}
