package com.ailanyin.admin.controller;

import com.ailanyin.admin.service.HxStorehouseService;
import com.ailanyin.common.result.AjaxResult;
import com.ailanyin.common.result.CommonPage;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.ExcelUtil;
import com.ailanyin.model.HxStorehouse;
import com.github.pagehelper.PageHelper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/21 0021 上午 9:42
 */

@RestController
@RequestMapping("/hx/storehouse")
@Api(tags = "科研生产:项目管理:库房信息管理")
public class HxStorehouseController {

    @Autowired
    private HxStorehouseService hxStorehouseService;

    @GetMapping("/list")
    @ApiOperation(value = "红峡库房信息列表")
    public CommonPage list(HxStorehouse hxStorehouse,
                           @RequestParam(value = "pageSize", required = false) Integer pageSize,
                           @RequestParam(value = "pageNum", required = false) Integer pageNum) {

        if (EmptyUtil.isNotEmpty(pageSize) && EmptyUtil.isNotEmpty(pageNum)) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<HxStorehouse> list = hxStorehouseService.selectList(hxStorehouse);
        return CommonPage.restPage(list);
    }

    @PostMapping("/importData")
    @ApiOperation(value = "导入Excel列表")
    //@PreAuthorize("hasAuthority('hx:productCompletion:import')")
    public AjaxResult importData(MultipartFile file) throws Exception {
        List<HxStorehouse> list = ExcelUtil.importExcel(file, HxStorehouse.class);
        hxStorehouseService.importData(list);
        return AjaxResult.success();
    }


    @PostMapping("/insert")
    public AjaxResult insert(@RequestBody HxStorehouse hxStorehouse) {
        hxStorehouseService.insert(hxStorehouse);
        return AjaxResult.success();
    }

    @GetMapping("/importTemplate")
    @ApiOperation(value = "导出模板")
    //@PreAuthorize("hasAuthority('system:user:import')")
    public AjaxResult importTemplate() throws Exception {
        return AjaxResult.success(ExcelUtil.exportExcel(new ArrayList<>(), "库房信息表", "库房信息", HxStorehouse.class, "库房信息"));
    }
}
