package com.ailanyin.admin.runner;

import com.ailanyin.admin.socket.SocketServerListenHandler;
import com.ailanyin.common.service.RedisService;
import com.ailanyin.mapper.HxCarLocationConfigMapper;
import com.ailanyin.model.HxCarLocationConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.ApplicationArguments;
import org.springframework.boot.ApplicationRunner;
import org.springframework.context.ApplicationContext;
import org.springframework.core.annotation.Order;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.stereotype.Component;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.lang.annotation.Annotation;
import java.lang.reflect.Method;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

/**
 * 项目启动后连接 socket 读卡器
 *
 * @author ailanyin
 * @version 1.0
 * @since 2022/1/15 0015 上午 9:52
 */

@Component
@Order(value = 2)
public class StartReaderRunner implements ApplicationRunner {

    @Autowired
    private ApplicationContext applicationContext;
    @Autowired
    private RedisService redisService;
    @Resource
    private HxCarLocationConfigMapper hxCarLocationConfigMapper;

    public static String database;

    @Override
    public void run(ApplicationArguments args) throws Exception {
        //将上传配置写进redis中
        writeConfigToRedis();
        SocketServerListenHandler socketServerListenHandler = new SocketServerListenHandler(27012);
        socketServerListenHandler.listenClientConnect();
    }

    private void writeConfigToRedis() {
        HxCarLocationConfig config = hxCarLocationConfigMapper.selectConfig();
        if (config == null) {
            HxCarLocationConfig defaultConfig = new HxCarLocationConfig();
            defaultConfig.setUploadInterval(2);
            hxCarLocationConfigMapper.insertConfig(defaultConfig);
            redisService.set(database +":business:config:uploadInterval",2);
            return;
        }

        redisService.set(database +":business:config:uploadInterval",config.getUploadInterval());
    }

    public String getDatabase() {
        return database;
    }

    @Value("${redis.database}")
    public void setDatabase(String database) {
        StartReaderRunner.database = database;
    }

}
