package com.ailanyin.admin.service.impl;

import com.ailanyin.common.exception.Asserts;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxCarLocationMapper;
import com.ailanyin.model.HxCarLocation;
import com.ailanyin.admin.service.HxCarLocationService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.DecimalFormat;
import java.util.Date;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2022-01-11 01:36:18
 */
@Service
public class HxCarLocationServiceImpl implements HxCarLocationService {

    @Resource
    private HxCarLocationMapper hxCarLocationMapper;

    @Override
    public List<HxCarLocation> getListByParam(HxCarLocation hxCarLocation) {
        return hxCarLocationMapper.selectList(hxCarLocation);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void insertHxCarLocation(HxCarLocation hxCarLocation) {
        checkCarIdIsExist(hxCarLocation);
        checkIsBind(hxCarLocation);
        hxCarLocation.setCreateTime(new Date());
        hxCarLocation.setLocationCardNumber(Integer.parseInt(hxCarLocation.getLocationCardNum()));
        hxCarLocationMapper.insertSelective(hxCarLocation);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateHxCarLocation(HxCarLocation hxCarLocation) {
        checkCarIdIsExist(hxCarLocation);
        checkIsBind(hxCarLocation);
        hxCarLocation.setLocationCardNumber(Integer.parseInt(hxCarLocation.getLocationCardNum()));
        hxCarLocationMapper.updateByPrimaryKeySelective(hxCarLocation);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteByIds(Long[] ids) {
        hxCarLocationMapper.deleteByIds(ids);
    }

    @Override
    public HxCarLocation getInfo(Long id) {
        return hxCarLocationMapper.selectByPrimaryKey(id);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void bindCarAndLocation(HxCarLocation hxCarLocation) {
        checkIsBind(hxCarLocation);
        hxCarLocation.setLocationCardNumber(Integer.parseInt(hxCarLocation.getLocationCardNum()));
        updateHxCarLocation(hxCarLocation);
    }

    @Override
    public void notBindCarAndLocation(HxCarLocation hxCarLocation) {
        hxCarLocationMapper.notBindCarAndLocation(hxCarLocation);
    }

    private void checkIsBind(HxCarLocation hxCarLocation) {
        HxCarLocation selectResult = hxCarLocationMapper.checkIsBind(hxCarLocation);
        if (EmptyUtil.isNotEmpty(selectResult)) {
            Asserts.fail("识别卡: " + hxCarLocation.getLocationCardNum()
                    + " 已经和汽车: " +
                    selectResult.getCarId() + " 绑定！");
        }

    }

    private void checkCarIdIsExist(HxCarLocation hxCarLocation) {
        HxCarLocation selectResult = hxCarLocationMapper.checkCarIdIsExist(hxCarLocation);
        if (EmptyUtil.isNotEmpty(selectResult)) {
            Asserts.fail("车牌: " + hxCarLocation.getCarId() + "已存在！");
        }
    }
}
