package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxCivilIncomeService;
import com.ailanyin.common.utils.DateUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxCivilContractMapper;
import com.ailanyin.mapper.HxCivilIncomeMapper;
import com.ailanyin.mapper.HxGeneralPlantConditionsMapper;
import com.ailanyin.model.HxCivilContract;
import com.ailanyin.model.HxCivilIncome;
import com.ailanyin.model.HxGeneralPlantConditions;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/15 0015 上午 11:26
 */

@Service
public class HxCivilIncomeServiceImpl implements HxCivilIncomeService {

    @Resource
    private HxCivilIncomeMapper hxCivilIncomeMapper;
    @Resource
    private HxGeneralPlantConditionsMapper hxGeneralPlantConditionsMapper;
    @Resource
    private HxCivilContractMapper hxCivilContractMapper;

    //type=1总厂情况/2=合同及产品/3本月情况

    private static String TYPE_1 = "1";
    private static String TYPE_2 = "2";
    private static String TYPE_3 = "3";

    @Override
    public List<HxCivilIncome> selectHxCivilIncomeList(HxCivilIncome hxCivilIncome) {
        return hxCivilIncomeMapper.selectList(hxCivilIncome);
    }

    @Override
    public void importData(List<HxCivilIncome> list) {
        list.forEach(hxCivilIncome -> {
            if (EmptyUtil.isNotEmpty(hxCivilIncome.getDeptName())) {
                if (checkIsExist(hxCivilIncome)) {
                    hxCivilIncomeMapper.updateSelective(hxCivilIncome);
                } else {
                    hxCivilIncomeMapper.insertSelective(hxCivilIncome);
                }
            }
        });
    }

    @Override
    public Map getCivilIndustryPic(String type) {
        Map returnMap = new HashMap(3);
        //type=1总厂情况/2=合同及产品/3本月情况
        if (TYPE_1.equals(type)) {
            HxGeneralPlantConditions conditions = new HxGeneralPlantConditions();
            returnMap.put("list", hxGeneralPlantConditionsMapper.selectList(conditions));
            returnMap.put("total", hxGeneralPlantConditionsMapper.selectTotal(DateUtil.getNowYear() + "-%"));
        }

        if (TYPE_2.equals(type)) {

            String year = DateUtil.getNowYear() + "-%";
            List<String> monthList = hxCivilContractMapper.getAllMonth();
            List<List<Map>> list = new ArrayList<>();
            monthList.forEach(
                    month -> {
                        List<Map> map = hxCivilContractMapper.selectCategoryByMonth(month + "-%");
                        handleMap(map);
                        list.add(map);
                    }
            );
            returnMap.put("list", list);
            returnMap.put("monthList", monthList);
            Map totalAndAmount = hxCivilContractMapper.selectTotalAndAmountByYear(year);
            totalAndAmount.putIfAbsent("amount", 0);
            returnMap.put("totalAndAmount", totalAndAmount);
            returnMap.put("categoryTotal", hxCivilContractMapper.selectCategoryTotalByYear(year));
        }

        if (TYPE_3.equals(type)) {
            HxCivilIncome hxCivilIncome = new HxCivilIncome();
            hxCivilIncome.setMonth(DateUtil.getDate("yyyy-MM"));
            List<HxCivilIncome> list = selectHxCivilIncomeList(hxCivilIncome);
            returnMap.put("list", EmptyUtil.isNotEmpty(list) ? list : selectHxCivilIncomeList(new HxCivilIncome()));
        }
        return returnMap;
    }

    private boolean checkIsExist(HxCivilIncome hxCivilIncome) {
        return hxCivilIncomeMapper.checkIsExist(hxCivilIncome) > 0;
    }

    private void handleMap(List<Map> mapList) {

        if (mapList.size() >= 3) {
            return;
        }

        List<String> categoryList = new ArrayList<>();
        categoryList.add("隔热");
        categoryList.add("稀土");
        categoryList.add("其他");

        for (Map map : mapList) {
            String category = map.get("category").toString();
            String planQuantity = map.get("planQuantity").toString();
            String realQuantity = map.get("realQuantity").toString();
            map.put("quantityRate", Float.valueOf(realQuantity) * 100 / Float.valueOf(planQuantity));
            categoryList.remove(category);
        }

        for (String catetory : categoryList) {
            Map map = new HashMap(3);
            //          "realQuantity": 86,
            //          "planQuantity": 91,
            //          "category": "其他"
            map.put("category", catetory);
            map.put("realQuantity", 0);
            map.put("planQuantity", 0);
            mapList.add(map);
        }
    }
}
