package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxDangerousPointService;
import com.ailanyin.common.service.RedisService;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.IpUtil;
import com.ailanyin.mapper.HxDangerousPointMapper;
import com.ailanyin.mapper.HxDangerousSourceMapper;
import com.ailanyin.mapper.HxDictMapper;
import com.ailanyin.model.HxDangerousPoint;
import com.ailanyin.model.HxDangerousSource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.*;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 下午 15:44
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxDangerousPointServiceImpl implements HxDangerousPointService {

    @Value("${hxDict.deptParentId}")
    private String deptParentId;
    @Value("${hxDict.pointLevelParentId}")
    private String pointLevelParentId;
    @Value("${hxDict.sourceLevelParentId}")
    private String sourceLevelParentId;
    @Value("${redis.database}")
    private String database;

    @Autowired
    private RedisService redisService;
    @Resource
    private HxDangerousPointMapper hxDangerousPointMapper;
    @Resource
    private HxDictMapper hxDictMapper;
    @Resource
    private HxDangerousSourceMapper hxDangerousSourceMapper;


    /**
     * 查询危险点列表
     *
     * @param hxDangerousPoint hxDangerousPoint
     * @return list
     */
    @Override
    public List<HxDangerousPoint> selectHxDangerousPointList(HxDangerousPoint hxDangerousPoint) {
        return hxDangerousPointMapper.selectHxDangerousPointList(hxDangerousPoint);
    }

    /**
     * 导入数据
     *
     * @param list list
     */
    @Override
    public void importData(List<HxDangerousPoint> list) {
        list.forEach(hxDangerousPoint -> {
            if (EmptyUtil.isNotEmpty(hxDangerousPoint.getPointName())) {
                if (checkIsExist(hxDangerousPoint.getPointName())) {
                    hxDangerousPointMapper.updateStatus(hxDangerousPoint);
                } else {
                    hxDangerousPoint.setCreateTime(new Date());
                    hxDangerousPointMapper.insertSelective(hxDangerousPoint);

                }
                handleRtmpToVideo(hxDangerousPoint);
            }
        });
    }

    /**
     * 获取大图
     *
     * @return map
     */
    @Override
    public Map getDangerPointBigPic() {
        Map<String,Object> returnMap = new LinkedHashMap<>(4);
        //All 危险源字典
        List<String> allDept = hxDictMapper.selectNameListByParentId(deptParentId);

        allDept.forEach(dept -> {
            returnMap.put(dept,hxDangerousPointMapper.selectAllLevelNumByDept(dept,pointLevelParentId));
        });
        returnMap.put("allLevel",hxDictMapper.selectNameListByParentId(pointLevelParentId));
        return returnMap;
    }

    /**
     * 中间危险点地图
     *
     * @return map
     */
    @Override
    public Map getDangerousMapBigPic() {
        Map returnMap = new HashMap(5);
        //危险点list
        List<HxDangerousPoint> points = hxDangerousPointMapper.selectHxDangerousPointList(new HxDangerousPoint());
        points.forEach(point -> {
            if (redisService.hasKey(database + ":rtmp:dangerousPoint" + point.getId())) {
                String url = redisService.get(database + ":rtmp:dangerousPoint" + point.getId()).toString();
                point.setRtmpAddress(url);
            }
        });
        int count = hxDangerousPointMapper.selectNullRtmpCount();
        if (points.size() > 0) {
            returnMap.put("rate",(points.size() - count) * 100/points.size());
        } else {
            returnMap.put("rate",0);
        }
        //危险源list
        //List<HxDangerousSource> sources = hxDangerousSourceMapper.selectHxDangerousSourceList(new HxDangerousSource());
        returnMap.put("pointLevelCount",hxDangerousPointMapper.selectAllLevelNumByDept(null,pointLevelParentId));
        returnMap.put("sourceLevelCount",hxDangerousSourceMapper.selectAllLevelNumByDept(null,sourceLevelParentId));
        returnMap.put("points",points);
        return returnMap;
    }

    @Override
    public void handleRtmpToVideo(HxDangerousPoint hxDangerousPoint) {
        if (EmptyUtil.isNotEmpty(hxDangerousPoint.getId()) && EmptyUtil.isNotEmpty(hxDangerousPoint.getRtmpAddress())) {
            System.out.println("开始推: " +hxDangerousPoint.getId() +" 号危险点");
            String[] cmd = new String[]{"sh", "-c", "nohup ffmpeg -re -i " + hxDangerousPoint.getRtmpAddress() + " -vcodec copy -acodec copy -f flv -y rtmp://127.0.0.1:1935/live/dangerousPoint" + hxDangerousPoint.getId() + "  >/opt/null 2>&1 &"};
            try {
                Runtime.getRuntime().exec(cmd);
            } catch (IOException e) {
                e.printStackTrace();
            }

            try {
                String url = "http://" + IpUtil.getLocalIp() + "/stream/live/dangerousPoint" + hxDangerousPoint.getId()+".flv";
                redisService.set(database + ":rtmp:dangerousPoint" + hxDangerousPoint.getId(), url);
            } catch (UnknownHostException e) {
                e.printStackTrace();
            }
        }
    }

    private boolean checkIsExist(String name) {
        return hxDangerousPointMapper.checkIsExist(name) > 0;
    }
}
