package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxHiddenDangerService;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.DateUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.StringUtil;
import com.ailanyin.mapper.HxHiddenDangerMapper;
import com.ailanyin.model.HxHiddenDanger;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/8 0008 下午 17:07
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxHiddenDangerServiceImpl implements HxHiddenDangerService {


    @Resource
    private HxHiddenDangerMapper hxHiddenDangerMapper;

    private static final String WORKSHOP = "1";
    private static final String GENERAL_FACTORY = "2";

    /**
     * 查询安全隐患列表
     *
     * @param hxHiddenDanger hxHiddenDanger
     * @return list
     */
    @Override
    public List<HxHiddenDanger> selectHxHiddenDangerList(HxHiddenDanger hxHiddenDanger) {
        return hxHiddenDangerMapper.selectHxHiddenDangerList(hxHiddenDanger);
    }

    /**
     * 导入
     *
     * @param list list
     */
    @Override
    public void importData(List<HxHiddenDanger> list) {
        list.forEach(hxHiddenDanger -> {
            if (EmptyUtil.isNotEmpty(hxHiddenDanger.getExistProblem())) {
                hxHiddenDanger.setCreateTime(new Date());
                hxHiddenDangerMapper.insertSelective(hxHiddenDanger);
            }
        });
    }

    /**
     * 大图
     *
     * @param type 1车间/=2总厂
     * @return map
     */
    @Override
    public Map getHiddenDangerBigPic(String type) {
        Map<String,Object> map = new HashMap<>(3);
        if (WORKSHOP.equals(type)) {
            String year = String.valueOf(DateUtil.getNowYear());
            HxHiddenDanger hxHiddenDanger = new HxHiddenDanger();
            hxHiddenDanger.setCheckDate(year);
            map.put("list",hxHiddenDangerMapper.selectHxHiddenDangerList(hxHiddenDanger));
            // 责任单位 = 车间
            map.put("mapList",hxHiddenDangerMapper.selectByYearGroupUnit(year));
        }

        if (GENERAL_FACTORY.equals(type)) {
            Integer nowYear = DateUtil.getNowYear();
            // 获取柱状图 所有月份 -> 个数
            List<Map<String,Integer>> monthCountList = hxHiddenDangerMapper.selectCountGroupByMonth();
            // 获取饼图
            // 获取所有分类
            List<String> categoryList = hxHiddenDangerMapper.getAllCategoryByYear(nowYear);
            List<Map> mapList = new ArrayList<>();
            categoryList.forEach(category -> {
                Integer count = hxHiddenDangerMapper.selectCountByCategoryAndYear(category,nowYear);
                Map<String,Object> categoryCountMap = new HashMap();
                categoryCountMap.put("category",category);
                categoryCountMap.put("count",count);
                mapList.add(categoryCountMap);
            });

            map.put("category",categoryList);
            map.put("mapList",mapList);
            map.put("monthList",monthCountList);
            map.put("total",hxHiddenDangerMapper.selectCountByCategoryAndYear(null,nowYear));
        }
        return map;
    }

}
