package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxMilitaryContractService;
import com.ailanyin.admin.service.HxMilitaryGeneralFactoryService;
import com.ailanyin.admin.service.HxMilitaryIncomeService;
import com.ailanyin.common.utils.DateUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxMilitaryContractMapper;
import com.ailanyin.mapper.HxMilitaryGeneralFactoryMapper;
import com.ailanyin.model.HxGeneralPlantConditions;
import com.ailanyin.model.HxMilitaryContract;
import com.ailanyin.model.HxMilitaryGeneralFactory;
import com.ailanyin.model.HxMilitaryIncome;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/16 0016 下午 18:35
 */

@Service
public class HxMilitaryGeneralFactoryServiceImpl implements HxMilitaryGeneralFactoryService {

    @Resource
    private HxMilitaryGeneralFactoryMapper hxMilitaryGeneralFactoryMapper;
    @Resource
    private HxMilitaryIncomeService hxMilitaryIncomeService;
    @Resource
    private HxMilitaryContractMapper hxMilitaryContractMapper;

    //type=1总厂情况/2=合同/3本月情况

    private static String TYPE_1 = "1";
    private static String TYPE_2 = "2";
    private static String TYPE_3 = "3";

    @Override
    public List<HxMilitaryGeneralFactory> selectList(HxMilitaryGeneralFactory hxMilitaryGeneralFactory) {
        return hxMilitaryGeneralFactoryMapper.selectList(hxMilitaryGeneralFactory);
    }

    @Override
    public void importData(List<HxMilitaryGeneralFactory> list) {
        list.forEach(hxMilitaryGeneralFactory -> {
            if (EmptyUtil.isNotEmpty(hxMilitaryGeneralFactory.getProductModel())) {
                if (checkIsExist(hxMilitaryGeneralFactory)) {
                    hxMilitaryGeneralFactoryMapper.updateSelective(hxMilitaryGeneralFactory);
                } else {
                    hxMilitaryGeneralFactoryMapper.insertSelective(hxMilitaryGeneralFactory);
                }
            }
        });
    }

    @Override
    public Map getMilitaryIndustryPic(String type) {
        Map returnMap = new HashMap(3);
        //type=1总厂情况/2=合同/3本月情况
        if (TYPE_1.equals(type)) {
            returnMap.put("list", hxMilitaryGeneralFactoryMapper.selectListGroupByMonth(null));
            returnMap.put("total", hxMilitaryGeneralFactoryMapper.selectTotal(DateUtil.getNowYear() + "-%"));
            returnMap.put("modelTotal", hxMilitaryGeneralFactoryMapper.selectModelTotal(DateUtil.getNowYear() + "-%"));
        }

        if (TYPE_2.equals(type)) {
            String year = DateUtil.getNowYear() + "-%";
            HxMilitaryContract hxMilitaryContract = new HxMilitaryContract();
            hxMilitaryContract.setContractDate(year);
            returnMap.put("list", hxMilitaryContractMapper.selectList(hxMilitaryContract));
            returnMap.put("totalAndAmount", hxMilitaryContractMapper.selectTotalAndAmountByYear(year));
        }

        if (TYPE_3.equals(type)) {
            HxMilitaryIncome hxMilitaryIncome = new HxMilitaryIncome();
            hxMilitaryIncome.setMonth(DateUtil.getDate("yyyy-MM"));
            List<HxMilitaryIncome> list = hxMilitaryIncomeService.selectList(hxMilitaryIncome);
            returnMap.put("list", EmptyUtil.isNotEmpty(list) ? list : hxMilitaryIncomeService.selectList(new HxMilitaryIncome()));
        }
        return returnMap;
    }

    private boolean checkIsExist(HxMilitaryGeneralFactory hxMilitaryGeneralFactory) {
        return hxMilitaryGeneralFactoryMapper.checkIsExist(hxMilitaryGeneralFactory) > 0;
    }
}
