package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxQualityPlanService;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxQualityPlanMapper;
import com.ailanyin.model.HxQualityPlan;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/9 0009 下午 16:49
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxQualityPlanServiceImpl implements HxQualityPlanService {

    @Resource
    private HxQualityPlanMapper hxQualityPlanMapper;

    private static String DEPT = "2";
    private static String GENERAL_FACTORY = "1";

    @Override
    public List<HxQualityPlan> selectHxQualityPlanList(HxQualityPlan hxQualityPlan) {
        return hxQualityPlanMapper.selectHxQualityPlanList(hxQualityPlan);
    }

    @Override
    public void importData(List<HxQualityPlan> list) {

        list.forEach(hxQualityPlan -> {
            if (EmptyUtil.isNotEmpty(hxQualityPlan.getDeptName())) {
                handleRate(hxQualityPlan);
                // 更新
                if (checkIsExist(hxQualityPlan.getDeptName(),hxQualityPlan.getMonth())) {
                    hxQualityPlanMapper.updateByDeptAndMonth(hxQualityPlan);
                }
                // 新增
                else {
                    hxQualityPlanMapper.insertSelective(hxQualityPlan);
                }
            }
        });

    }

    @Override
    public List<Map> getQualityPlan(String type) {
        List<Map> list = new ArrayList<>();

        if (GENERAL_FACTORY.equals(type)) {
            list.addAll(hxQualityPlanMapper.selectGeneralFactory());
        }

        if (DEPT.equals(type)) {
            list.addAll(hxQualityPlanMapper.selectDept());
        }
        return list;
    }

    private boolean checkIsExist(String deptName,String month) {
        return hxQualityPlanMapper.checkIsExist(deptName,month) > 0;
    }

    private void handleRate(HxQualityPlan hxQualityPlan) {
        hxQualityPlan.setCompleteRate(BigDecimalUtil.calculateCompletionRate(
                hxQualityPlan.getCompleteNumber(),
                hxQualityPlan.getPlanNumber()
        ));
    }
}
