package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxQualityProblemService;
import com.ailanyin.common.exception.Asserts;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.DateUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxQualityProblemMapper;
import com.ailanyin.model.HxQualityProblem;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/10 0010 下午 15:42
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxQualityProblemServiceImpl implements HxQualityProblemService {

    @Resource
    private HxQualityProblemMapper hxQualityProblemMapper;

    private static String MONTH = "2";
    private static String YEAR = "1";

    @Override
    public List<HxQualityProblem> selectHxQualityProblemList(HxQualityProblem hxQualityProblem) {
        return hxQualityProblemMapper.selectHxQualityProblemList(hxQualityProblem);
    }


    @Override
    public void importData(List<HxQualityProblem> list) {
        list.forEach(hxQualityProblem -> {
            if (EmptyUtil.isNotEmpty(hxQualityProblem.getName())) {
                if (EmptyUtil.isEmpty(hxQualityProblem.getDimension()) ||
                        // /3 因为 dimension = 1/2/3
                        hxQualityProblem.getDimension()/4 > 0) {
                    Asserts.fail("维度只能是1，2，3，输入错误！");
                }
                hxQualityProblem.setCompleteRate(BigDecimalUtil.calculateCompletionRate(
                        hxQualityProblem.getCompletedTotal(),
                        hxQualityProblem.getProblemTotal()
                ));
                // 更新
                if (checkIsExist(hxQualityProblem)) {
                    hxQualityProblemMapper.updateSelective(hxQualityProblem);
                }
                // 新增
                else {
                    hxQualityProblemMapper.insertSelective(hxQualityProblem);
                }

            }
        });
    }

    @Override
    public Map getQualityProblemByType(String type) {
        Map returnMap = new HashMap(2);

        List<Map> list = new ArrayList<>();
        //dimension = 1/2/3 型号/类别/部门
        if (MONTH.equals(type)) {

/*            for (int j = 1; j < 4; j++) {
                Map map = new HashMap(2);
                map.put("dimension",j);
                map.put("value",hxQualityProblemMapper.selectByMonthAndDimension(DateUtil.dateTimeNow("yyyy-MM"),j));
                list.add(map);
            }*/
            List<String> monthList = hxQualityProblemMapper.getAllMonth();
            returnMap.put("allName",hxQualityProblemMapper.getAllName());
            monthList.forEach(month -> {
                Map map = new HashMap(2);
                List<Map> maps = hxQualityProblemMapper.selectByMonthAndDimension(month, 2);
                map.put(month,maps);
                list.add(map);
            });
        }

        if (YEAR.equals(type)) {
            for (int j = 1; j < 4; j++) {
                Map map = new HashMap(2);
                map.put("dimension",j);
                map.put("value",hxQualityProblemMapper.selectByYearAndDimension(DateUtil.getNowYear() + "-%",j));
                list.add(map);
            }
        }
        returnMap.put("list",list);
        return returnMap;
    }

    private boolean checkIsExist(HxQualityProblem hxQualityProblem) {
        return hxQualityProblemMapper.checkIsExist(hxQualityProblem) > 0;
    }
}
