package com.ailanyin.admin.service.impl;

import com.ailanyin.common.exception.Asserts;
import com.ailanyin.common.utils.IpUtil;
import com.ailanyin.mapper.HxReaderInfoMapper;
import com.ailanyin.model.HxReaderInfo;
import com.ailanyin.admin.service.HxReaderInfoService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;

/**
* @author ailanyin
* @version 1.0
* @since 2022-01-15 08:59:27
*/
@Service
public class HxReaderInfoServiceImpl implements HxReaderInfoService {

    @Resource
    private HxReaderInfoMapper hxReaderInfoMapper;

    @Override
    public List<HxReaderInfo> getListByParam(HxReaderInfo hxReaderInfo) {
        return hxReaderInfoMapper.selectList(hxReaderInfo);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void insertHxReaderInfo(HxReaderInfo hxReaderInfo) {
        checkData(hxReaderInfo);
        hxReaderInfo.setCreateTime(new Date());
        // ip 192.168.0.125 -> id 125
        hxReaderInfo.setId(Long.parseLong(hxReaderInfo.getReaderIp().substring(hxReaderInfo.getReaderIp().lastIndexOf(".") + 1)));
        hxReaderInfoMapper.insertSelective(hxReaderInfo);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateHxReaderInfo(HxReaderInfo hxReaderInfo) {
        checkData(hxReaderInfo);
        hxReaderInfoMapper.updateByPrimaryKeySelective(hxReaderInfo);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void deleteByIds(Long[] ids) {
        hxReaderInfoMapper.deleteByIds(ids);
    }

    @Override
    public HxReaderInfo getInfo(Long id) {
        return hxReaderInfoMapper.selectByPrimaryKey(id);
    }

    private void checkData(HxReaderInfo hxReaderInfo) {
        if (!IpUtil.checkIpIsTrue(hxReaderInfo.getReaderIp())) {
            Asserts.fail(hxReaderInfo.getReaderIp() +" 格式不正确!");
        }

        if (hxReaderInfoMapper.checkIsExist(hxReaderInfo) > 0) {
            Asserts.fail(hxReaderInfo.getReaderIp() +" 已存在!");
        }
    }
}
