package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxStorehouseService;
import com.ailanyin.common.exception.Asserts;
import com.ailanyin.common.utils.Base64Util;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.mapper.HxStorehouseMapper;
import com.ailanyin.model.HxStorehouse;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/21 0021 上午 9:43
 */

@Service
public class HxStorehouseServiceImpl implements HxStorehouseService {

    @Resource
    private HxStorehouseMapper hxStorehouseMapper;

    @Override
    public List<HxStorehouse> selectList(HxStorehouse hxStorehouse) {
        return hxStorehouseMapper.selectList(hxStorehouse);
    }

    @Override
    public void importData(List<HxStorehouse> list) {
        list.forEach(hxStorehouse -> {
            if (EmptyUtil.isNotEmpty(hxStorehouse.getNumberNo())) {
                if (checkIsExist(hxStorehouse)) {
                    hxStorehouseMapper.updateSelective(hxStorehouse);
                } else {
                    hxStorehouseMapper.insertSelective(hxStorehouse);
                }
            }
        });
    }

    @Override
    public void insert(HxStorehouse hxStorehouse) {
        if (EmptyUtil.isEmpty(hxStorehouse)
                || !checkAuth(hxStorehouse.getAuth())) {
            Asserts.fail("鉴权失败");
        }
        if (EmptyUtil.isNotEmpty(hxStorehouse.getNumberNo())) {
            if (checkIsExist(hxStorehouse)) {
                hxStorehouseMapper.updateSelective(hxStorehouse);
            } else {
                hxStorehouseMapper.insertSelective(hxStorehouse);
            }
        }
    }

    private boolean checkIsExist(HxStorehouse hxStorehouse) {
        return hxStorehouseMapper.checkIsExist(hxStorehouse) > 0;
    }

    /**
     * 取当前时间得unix时间戳(秒级)
     * 计算时间戳每一位相加得和取最后一位拼接在时间戳后面
     *
     * 如 1646204542
     * 相加(1+6+4+6+2+0+4+5+4+2 = 34 )
     * 34取最后一位 4
     * 拼接时间戳就是16462045424
     * base64加密16462045424
     * 最后得到MTY0NjIwNDU0MjQ=
     * @param authStr base64加密字符串
     * @return 鉴权成功 or 失败
     */
    private boolean checkAuth(String authStr) {
        if (EmptyUtil.isEmpty(authStr)) {
            return false;
        }

        // base64解码
        try {
            String auth = new String(Base64Util.decrypt(authStr));
            if (auth.length() != 11) {
                return false;
            }

            Integer result = 0;
            String[] unixArray = auth.substring(0, auth.length() - 1).split("");
            for (String unix : unixArray) {
                result = result + Integer.parseInt(unix);
            }

            return result.toString().substring(result.toString().length() - 1).equals(auth.substring(auth.length() - 1));
        } catch (Exception e) {
            return false;
        }
    }
}
