package com.ailanyin.admin.service.impl;

import cn.hutool.core.util.RuntimeUtil;
import com.ailanyin.admin.service.HxDangerousPointService;
import com.ailanyin.admin.service.HxVideoService;
import com.ailanyin.admin.service.HxVideoSystemService;
import com.ailanyin.admin.service.HxWorkHomeInfoService;
import com.ailanyin.common.service.RedisService;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.FileUtil;
import com.ailanyin.common.utils.IpUtil;
import com.ailanyin.mapper.HxVideoMapper;
import com.ailanyin.mapper.HxVideoSystemMapper;
import com.ailanyin.model.HxDangerousPoint;
import com.ailanyin.model.HxVideo;
import com.ailanyin.model.HxVideoSystem;
import com.ailanyin.model.HxWorkHomeInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.File;
import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/23 0023 下午 15:17
 */

@Service
public class HxVideoServiceImpl implements HxVideoService {

    @Resource
    private HxVideoMapper hxVideoMapper;
    @Value("${upload.path}")
    private String path;
    @Value("${redis.database}")
    private String database;

    @Autowired
    private RedisService redisService;
    @Autowired
    private HxDangerousPointService hxDangerousPointService;
    @Autowired
    private HxVideoSystemService hxVideoSystemService;
    @Autowired
    private HxWorkHomeInfoService hxWorkHomeInfoService;

    @PostConstruct
    public void init() {
        System.out.println("视频推流运行开始...");
        handlePlayVideo();
        System.out.println("视频推流运行成功...");
    }

    @Override
    public List<HxVideo> selectList(HxVideo hxVideo) {
        return hxVideoMapper.selectList(hxVideo);
    }

    @Override
    public void addHxVideo(HxVideo hxVideo) {
        handleFileAddress(hxVideo);
        hxVideoMapper.insertSelective(hxVideo);
        handlePlayVideo();
    }

    @Override
    public void updateHxVideo(HxVideo hxVideo) {
        handleFileAddress(hxVideo);
        hxVideoMapper.updateByPrimaryKeySelective(hxVideo);
        handlePlayVideo();
    }

    @Override
    public void delHxVideoById(Long hxVideoId) {
        hxVideoMapper.deleteByPrimaryKey(hxVideoId);
        handlePlayVideo();
    }

    @Override
    public String getVideoByType(String type) {
        if ("1".equals(type)) {
            return redisService.get(database + ":rtmp:reward_punishment_video").toString();
        } else {
            return redisService.get(database + ":rtmp:classic_cases_video").toString();
        }
    }


    private void handleFileAddress(HxVideo hxVideo) {
        if (EmptyUtil.isNotEmpty(hxVideo.getVideoFileName())) {
            if (hxVideo.getVideoFileName().startsWith("http")) {
                hxVideo.setVideoFileName(
                        hxVideo.getVideoFileName().substring(hxVideo.getVideoFileName().lastIndexOf("/") + 1)
                );
            }
        }
    }

    private void handlePlayVideo() {
        killFfmpeg();
        try {
            Thread.sleep(200);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }

        // 安全点
        List<HxDangerousPoint> pointList = hxDangerousPointService.selectHxDangerousPointList(new HxDangerousPoint());
        pointList.forEach(hxDangerousPoint -> {
            hxDangerousPointService.handleRtmpToVideo(hxDangerousPoint);
        });

        // 视频实况信息
        List<HxVideoSystem> videoSystemList = hxVideoSystemService.selectHxVideoSystemList(new HxVideoSystem());
        videoSystemList.forEach(hxVideoSystem -> {
            hxVideoSystemService.handleRtmpToVideo(hxVideoSystem);
        });

        // 工房
        List<HxWorkHomeInfo> homeInfoList = hxWorkHomeInfoService.selectList(new HxWorkHomeInfo());
        homeInfoList.forEach(hxWorkHomeInfo -> {
            hxWorkHomeInfoService.handleRtmpToVideo(hxWorkHomeInfo);
        });
        //查询所有
        for (int i = 1; i < 3; i++) {
            String category = String.valueOf(i);
            List<String> fileList = hxVideoMapper.selectFileByCategory(category);
            List<String> newList = new ArrayList<>();
            fileList.forEach(file -> {
                file = "file '" + file + "'";
                newList.add(file);
            });

            String path = updateFile(category);
            if (EmptyUtil.isNotEmpty(path)) {
                cn.hutool.core.io.FileUtil.writeLines(newList, path, "utf-8", false);
                try {
                    Thread.sleep(200);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }

                restartFfmpeg(path);
            }
        }
    }

    private String updateFile(String category) {
        String fileName = "";
        if ("1".equals(category)) {
            fileName = "reward_punishment_video.txt";
        } else {
            fileName = "classic_cases_video.txt";
        }
        // 新建文件
        File newFile = FileUtil.getAbsoluteFile(fileName, path);
        String path = newFile.getAbsolutePath();
        if (!newFile.exists()) {
            try {
                if (!newFile.createNewFile()) {
                    System.out.println(path + "创建失败！");
                    return null;
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return path;
    }

    private void killFfmpeg() {
        String[] cmd = new String[]{"sh", "-c", "ps aux | grep \"ffmpeg\" |grep -v grep| cut -c 9-15 | xargs kill -9"};
        try {
            Runtime.getRuntime().exec(cmd);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private void restartFfmpeg(String path) {
        String fileName = path.substring((path.lastIndexOf("/") + 1), path.lastIndexOf("."));
        // ffmpeg -stream_loop -1 -re -f concat -safe 0 -i a.txt -vcodec copy -acodec copy -f flv -y rtmp://192.168.0.148:1935/live/livestream
        System.out.println("开始推: " +fileName);
        String[] cmd = new String[]{"sh", "-c", "nohup ffmpeg -stream_loop -1 -re -f concat -safe 0 -i " + path + " -vcodec copy -acodec copy -f flv -y rtmp://127.0.0.1:1935/live/" + fileName + "  >/opt/null 2>&1 &"};

        try {
            Runtime.getRuntime().exec(cmd);
        } catch (IOException e) {
            e.printStackTrace();
        }

        try {
            Thread.sleep(500);
        } catch (Exception e) {
            e.printStackTrace();
        }


        try {
            String url = "http://" + IpUtil.getLocalIp() + "/stream/live/" + fileName + ".flv";
            redisService.set(database + ":rtmp:" + fileName, url);
        } catch (UnknownHostException e) {
            e.printStackTrace();
        }
    }
}
