package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxVideoSystemService;
import com.ailanyin.common.service.RedisService;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.IpUtil;
import com.ailanyin.mapper.HxVideoSystemMapper;
import com.ailanyin.model.HxVideoSystem;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/10 0010 上午 9:11
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class HxVideoSystemServiceImpl implements HxVideoSystemService {

    @Resource
    private HxVideoSystemMapper hxVideoSystemMapper;
    @Value("${redis.database}")
    private String database;

    @Autowired
    private RedisService redisService;

    @Override
    public List<HxVideoSystem> selectHxVideoSystemList(HxVideoSystem hxVideoSystem) {
        List<HxVideoSystem> list = hxVideoSystemMapper.selectHxVideoSystemList(hxVideoSystem);
        list.forEach(hxVideo -> {
            if (redisService.hasKey(database + ":rtmp:video" + hxVideo.getId())) {
                String url = redisService.get(database + ":rtmp:video" + hxVideo.getId()).toString();
                hxVideo.setVideoAddress(url);
            }
        });
        return list;
    }

    @Override
    public void importData(List<HxVideoSystem> list) {
        list.forEach(hxVideoSystem -> {
            if (EmptyUtil.isNotEmpty(hxVideoSystem.getVideoName())) {
                hxVideoSystemMapper.insertSelective(hxVideoSystem);
                handleRtmpToVideo(hxVideoSystem);
            }
        });
    }

    @Override
    public void handleRtmpToVideo(HxVideoSystem hxVideoSystem) {
        if (EmptyUtil.isNotEmpty(hxVideoSystem.getId()) && EmptyUtil.isNotEmpty(hxVideoSystem.getVideoAddress())) {
            System.out.println("开始推: " +hxVideoSystem.getVideoName() +" 实况信息");
            String[] cmd = new String[]{"sh", "-c", "nohup ffmpeg -re -i " + hxVideoSystem.getVideoAddress() + " -vcodec copy -acodec copy -f flv -y rtmp://127.0.0.1:1935/live/video" + hxVideoSystem.getId() + "  >/opt/null 2>&1 &"};
            try {
                Runtime.getRuntime().exec(cmd);
            } catch (IOException e) {
                e.printStackTrace();
            }
            try {
                String url = "http://" + IpUtil.getLocalIp() + "/stream/live/video" + hxVideoSystem.getId()+".flv";
                redisService.set(database + ":rtmp:video" + hxVideoSystem.getId(), url);
            } catch (UnknownHostException e) {
                e.printStackTrace();
            }
        }
    }
}
