package com.ailanyin.admin.service.impl;

import com.ailanyin.admin.service.HxWorkHomeInfoService;
import com.ailanyin.common.service.RedisService;
import com.ailanyin.common.utils.BigDecimalUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.IpUtil;
import com.ailanyin.mapper.HxWorkHomeInfoMapper;
import com.ailanyin.model.HxWorkHomeInfo;
import com.ailanyin.model.HxWorkHomeInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Arrays;
import java.util.List;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2021/12/23 0023 下午 18:42
 */

@Service
public class HxWorkHomeInfoServiceImpl implements HxWorkHomeInfoService {
    @Resource
    private HxWorkHomeInfoMapper hxWorkHomeInfoMapper;
    @Value("${redis.database}")
    private String database;

    @Autowired
    private RedisService redisService;

    @Override
    public List<HxWorkHomeInfo> selectList(HxWorkHomeInfo hxWorkHomeInfo) {
        return hxWorkHomeInfoMapper.selectList(hxWorkHomeInfo);
    }

    @Override
    public void importData(List<HxWorkHomeInfo> list) {
        list.forEach(hxWorkHomeInfo -> {
            if (EmptyUtil.isNotEmpty(hxWorkHomeInfo.getWorkHomeName())) {
                if (checkIsExist(hxWorkHomeInfo)) {
                    hxWorkHomeInfoMapper.updateSelective(hxWorkHomeInfo);
                } else {
                    hxWorkHomeInfoMapper.insertSelective(hxWorkHomeInfo);
                }
                handleRtmpToVideo(hxWorkHomeInfo);
            }
        });
    }

    @Override
    public List<HxWorkHomeInfo> getHxWorkHomePic() {
        HxWorkHomeInfo info = new HxWorkHomeInfo();
        info.setWorkFlag("是");
        List<HxWorkHomeInfo> list = selectList(info);
        list.forEach(hxWorkHomeInfo -> {
            if (redisService.hasKey(database + ":rtmp:hxWorkHomeInfo" + hxWorkHomeInfo.getId())) {
                String url = redisService.get(database + ":rtmp:hxWorkHomeInfo" + hxWorkHomeInfo.getId()).toString();
                hxWorkHomeInfo.setAvAddress(url);
            }

            if (hxWorkHomeInfo.getUsers() != null) {
                hxWorkHomeInfo.setUserList(Arrays.asList(hxWorkHomeInfo.getUsers().split(",")));
            }
        });
        return list;
    }

    @Override
    public void handleRtmpToVideo(HxWorkHomeInfo hxWorkHomeInfo) {
        if (EmptyUtil.isNotEmpty(hxWorkHomeInfo.getId()) && EmptyUtil.isNotEmpty(hxWorkHomeInfo.getAvAddress())) {
            System.out.println("开始推: " + hxWorkHomeInfo.getWorkHomeName() + " 工房");
            String[] cmd = new String[]{"sh", "-c", "nohup ffmpeg -re -i " + hxWorkHomeInfo.getAvAddress() + " -vcodec copy -acodec copy -f flv -y rtmp://127.0.0.1:1935/live/hxWorkHomeInfo" + hxWorkHomeInfo.getId() + "  >/opt/null 2>&1 &"};
            try {
                Runtime.getRuntime().exec(cmd);
            } catch (IOException e) {
                e.printStackTrace();
            }

            try {
                String url = "http://" + IpUtil.getLocalIp() + "/stream/live/hxWorkHomeInfo" + hxWorkHomeInfo.getId() + ".flv";
                redisService.set(database + ":rtmp:hxWorkHomeInfo" + hxWorkHomeInfo.getId(), url);
            } catch (UnknownHostException e) {
                e.printStackTrace();
            }
        }
    }

    private boolean checkIsExist(HxWorkHomeInfo hxWorkHomeInfo) {
        return hxWorkHomeInfoMapper.checkIsExist(hxWorkHomeInfo) > 0;
    }

}
