package com.ailanyin.admin.socket;

import com.ailanyin.admin.runner.StartReaderRunner;
import com.ailanyin.common.service.RedisService;
import com.ailanyin.common.utils.ConvertUtil;
import com.ailanyin.common.utils.EmptyUtil;
import com.ailanyin.common.utils.ReaderUtil;
import com.ailanyin.common.utils.SpringUtil;
import com.ailanyin.mapper.HxCarLocationLogMapper;
import com.ailanyin.mapper.HxCarLocationMapMapper;
import com.ailanyin.mapper.HxCarLocationMapper;
import com.ailanyin.mapper.HxReaderInfoMapper;
import com.ailanyin.model.HxCarLocation;
import com.ailanyin.model.HxCarLocationLog;
import com.ailanyin.model.HxCarLocationMap;
import com.ailanyin.model.HxReaderInfo;
import com.ailanyin.security.service.WebSocketService;
import com.alibaba.fastjson.JSON;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.Socket;
import java.text.DecimalFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @author ailanyin
 * @version 1.0
 * @since 2022/1/15 0015 下午 13:35
 */
public class SocketServerClientHandler extends Thread {
    /**
     * 每个消息通过Socket进行传输
     */
    private Socket clientConnectSocket;

    private HxReaderInfoMapper hxReaderInfoMapper = SpringUtil.getBean("hxReaderInfoMapper");

    private HxCarLocationLogMapper hxCarLocationLogMapper = SpringUtil.getBean("hxCarLocationLogMapper");

    private HxCarLocationMapper hxCarLocationMapper = SpringUtil.getBean("hxCarLocationMapper");

    private RedisService redisService = SpringUtil.getBean("redisService");

    private HxCarLocationMapMapper hxCarLocationMapMapper = SpringUtil.getBean("hxCarLocationMapMapper");

    private DecimalFormat decimalFormat = new DecimalFormat(".00");

    private String database = StartReaderRunner.database;

    public SocketServerClientHandler(Socket clientConnectSocket) {
        this.clientConnectSocket = clientConnectSocket;
    }

    @Override
    public void run() {
        try {
            InputStream is = clientConnectSocket.getInputStream();
            BufferedReader br = new BufferedReader(new InputStreamReader(is));
            byte[] buf = new byte[11];
            int line = 0;
            while ((line = is.read(buf)) != -1) {
                String inputStreamStr = bytesToHexFun3(buf, true);
                // 5A FF 08 00 00 01 60 7B 00 00 C3
                // 是自动上报
                if (ReaderUtil.checkActiveInitiative(inputStreamStr)) {
                    //获取读卡器标识
                    long readerId = Long.parseLong(inputStreamStr.substring(3, 5), 16);
                    HxReaderInfo hxReaderInfo = hxReaderInfoMapper.selectByPrimaryKey(readerId);
                    if (EmptyUtil.isNotEmpty(hxReaderInfo)) {
                        createHxCarLocationLog(inputStreamStr, hxReaderInfo);
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private boolean checkIsNeedUpload(long cardNumber) {
        /*if (redisService.hasKey(database + ":business:uploadInterval:" + cardNumber)) {
            return false;
        }
        redisService.set(database + ":business:uploadInterval:" + cardNumber, cardNumber, Integer.valueOf(redisService.get(database + ":business:config:uploadInterval").toString()));
*/
        return true;
    }

    /**
     * 将字节数组转换成十六进制字符串
     *
     * @param bytes 字节数组
     * @param flag  是否每一个字节后补空格
     * @return 十六进制字符串
     */
    public static final String bytesToHexFun3(byte[] bytes, boolean flag) {
        StringBuilder buf = new StringBuilder(bytes.length * 2);
        for (byte b : bytes) {
            buf.append(String.format("%02x", new Integer(b & 0xFF)));
            if (flag) {
                buf.append(" ");
            }
        }

        if (flag) {
            return buf.toString().substring(0, buf.toString().length() - 1).toUpperCase();
        }
        return buf.toString().toUpperCase();
    }

    private void createHxCarLocationLog(String inputStreamStr, HxReaderInfo hxReaderInfo) {

        String[] split = inputStreamStr.split(" ");
        int cardNumber = Integer.parseInt(split[4] + split[5] + split[6] + split[7], 16);

        //检查是否需要新增
        if (checkIsNeedUpload(cardNumber)) {
            HxCarLocation hxCarLocation = hxCarLocationMapper.selectByCardNumber(cardNumber);
            if (EmptyUtil.isNotEmpty(hxCarLocation)) {
                createHxCarLocationLog(hxCarLocation, hxReaderInfo, split);
            }
        }
    }

    private void createHxCarLocationLog(HxCarLocation hxCarLocation, HxReaderInfo hxReaderInfo, String[] split) {
        HxCarLocationLog log = new HxCarLocationLog();
        //距离
        Integer distance = ReaderUtil.calculateDistance(split[9]);
        if (distance >= 100) {
            return;
        }
        //多次进入或出去公房则不记录
        if (checkIsManyLog(hxReaderInfo, distance, hxCarLocation.getLocationCardNum(), hxReaderInfo.getId())) {
            return;
        }
        log.setDistance(distance);
        log.setStatus(hxReaderInfo.getRecordDistance() < distance ? "0":"1");
        //低电压
        log.setLowVoltage(String.valueOf(Integer.parseInt(split[8], 16)));
        //读卡器id
        log.setReadId(hxReaderInfo.getId());
        //读卡器名称
        log.setReadName(hxReaderInfo.getReaderName());
        //与正北夹角
        log.setNorthAngle(hxReaderInfo.getNorthAngle());
        //汽车横坐标
        log.setCarAbscissa(calculationAbscissa(hxReaderInfo, distance));
        //汽车纵坐标
        log.setCarOrdinate(calculationOrdinate(hxReaderInfo, distance));
        //车牌号
        log.setCarId(hxCarLocation.getCarId());
        //驾驶人姓名
        log.setDriverName(hxCarLocation.getDriverName());
        //驾驶人手机号
        log.setDriverPhone(hxCarLocation.getDriverPhone());
        //卡编号
        log.setCardNumber(hxCarLocation.getLocationCardNum());
        log.setCreateTime(new Date());
        hxCarLocationLogMapper.insertSelective(log);
        try {
            Map map = new HashMap(1);
            map.put("isLocationUpdate", log);
            WebSocketService.BroadCastInfo(JSON.toJSONString(map));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    private boolean checkIsManyLog(HxReaderInfo hxReaderInfo, Integer distance, String cardNum, Long readerInfoId) {

        Integer lastDistance = hxCarLocationLogMapper.selectLastLogDistanceByCardNumAndReadId(cardNum, readerInfoId);

        if (lastDistance == null) {
            return false;
        }

        if (lastDistance > hxReaderInfo.getRecordDistance() && distance > hxReaderInfo.getRecordDistance()) {
            return true;
        }

        if (lastDistance < hxReaderInfo.getRecordDistance() && distance < hxReaderInfo.getRecordDistance()) {
            return true;
        }

        return false;
    }

    private String calculationAbscissa(HxReaderInfo hxReaderInfo, Integer distance) {
        HxCarLocationMap hxCarLocationMap = getHxCarLocationMap();
        return String.valueOf(100 * (Float.valueOf(calculationSin(distance, hxReaderInfo.getNorthAngle())) * hxCarLocationMap.getScale()
                + (hxCarLocationMap.getXPixel() * hxReaderInfo.getAbscissa() / 100)) / hxCarLocationMap.getXPixel());
    }

    private String calculationOrdinate(HxReaderInfo hxReaderInfo, Integer distance) {
        HxCarLocationMap hxCarLocationMap = getHxCarLocationMap();
        return String.valueOf(100 * (Float.valueOf(calculationCos(distance, hxReaderInfo.getNorthAngle())) * hxCarLocationMap.getScale()
                + (hxCarLocationMap.getYPixel() * hxReaderInfo.getOrdinate() / 100)) / hxCarLocationMap.getYPixel());
    }

    private String calculationSin(Integer coordinate, Integer northAngle) {
        return decimalFormat.format(coordinate * Math.sin(Math.toRadians(northAngle)));
    }

    private String calculationCos(Integer coordinate, Integer northAngle) {
        return decimalFormat.format(coordinate * Math.cos(Math.toRadians(northAngle)));
    }

    private HxCarLocationMap getHxCarLocationMap() {
        if (redisService.hasKey(database + ":business:carLocationMap")) {
            return (HxCarLocationMap) redisService.get(database + ":business:carLocationMap");
        }

        HxCarLocationMap map = hxCarLocationMapMapper.selectList(new HxCarLocationMap()).get(0);
        redisService.set(database + ":business:carLocationMap", map);
        return map;
    }
}
