package com.ailanyin.common.utils;

/**
 * 阅读器工具类
 *
 * @author ailanyin
 * @version 1.0
 * @since 2022/1/14 0014 上午 9:49
 */
public class ReaderUtil {

    /**
     * 阅读器主动上报帧头 5A
     */
    private static final String ACTIVE_INITIATIVE_HEAD = "5A";
    /**
     * 阅读器主动上报长度 08
     */
    private static final String ACTIVE_INITIATIVE_LENGTH = "08";
    /**
     * 阅读器操作执行的结果 00 表示正常
     */
    private static final String ACTIVE_INITIATIVE_STATUS_OK = "00";

    /**
     * 检查阅读器主动上报数据的真实性
     *
     * @param data
     * @return
     */
    public static boolean checkActiveInitiative(String data) {
        // 5A FF 08 00 00 01 60 7B 00 00 C3
        // 5A FF 08 00 00 01 62 87 00 2C 89
        if (!ACTIVE_INITIATIVE_HEAD.equals(data.substring(0, 2))) {
            return false;
        }

        if (!ACTIVE_INITIATIVE_LENGTH.equals(data.substring(6, 8))) {
            return false;
        }

        if (!ACTIVE_INITIATIVE_STATUS_OK.equals(data.substring(9, 11))) {
            return false;
        }

        if (!checkActiveInitiativeData(data)) {
            return false;
        }

        return true;
    }

    private static boolean checkActiveInitiativeData(String data) {
        // 5A FF 08 00 00 01 60 7B 00 00 C3
        // (5A+FF+08+00+00+01+60+7B+00+00) 相加取反加1，取最后两个字节位 和 最后C3比较
        String result = "";
        String[] s1 = data.split(" ");
        for (int i = 0; i < s1.length - 1; i++) {
            if (EmptyUtil.isNotEmpty(s1[i])) {
                result = ConvertUtil.binaryAdd(result, ConvertUtil.hex2Binary(s1[i]));
            }
        }
        String s2 = ConvertUtil.binaryAdd(ConvertUtil.binaryReverse(result), "1");
        return s2.substring(s2.length() - 8).equals(ConvertUtil.hex2Binary(s1[s1.length - 1]));
    }

    public static Integer calculateDistance(String rssi) {
        //十六进制 -> 十进制
        int distance = Integer.parseInt(rssi, 16);

        // 2A-2C
        if (distance >= 42 && distance <= 44) {
            return 0;
        }
        // 2D-2E
        if (distance >= 45 && distance <= 46) {
            return 5;
        }
        // 2F-32
        if (distance >= 47 && distance <= 50) {
            return 10;
        }
        // 33-36
        if (distance >= 51 && distance <= 54) {
            return 15;
        }
        // 38-3E
        if (distance >= 56 && distance <= 62) {
            return 25;
        }
        // 3F-42
        if (distance >= 63 && distance <= 66) {
            return 50;
        }
        // 43-47
        if (distance >= 67 && distance <= 71) {
            return 80;
        }
        // 48-50
        if (distance >= 72 && distance <= 80) {
            return 110;
        }
        // 51-59
        if (distance >= 81 && distance <= 89) {
            return 150;
        }

        // 异常情况
        return 200;
    }

    public static void main(String[] args) {

        System.out.println(checkActiveInitiativeData("5A FF 08 00 00 01 60 7B 00 00 C3"));
    }
}
